@@ -1,5 +1,5 @@
 
--- libquvi-scripts v0.4.14
+-- libquvi-scripts v0.4.17
 -- Copyright (C) 2010,2012,2013  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -50,7 +50,7 @@ function parse(self)
     self.title = p:match('"og:title" content="(.-)"')
                   or error('no match: media title')
 
-    local u = p:match("(http://movies.-)'")
+    local u = p:match('(http://movies.-)["\']')
                 or error("no match: media stream URL")
 
     self.id = u:match("/%d+/(%d+)%.%w+") or error("no match: media ID")
