@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.14
--- Copyright (C) 2012  Toni Gundogdu <legatvs@gmail.com>
+-- libquvi-scripts v0.4.17
+-- Copyright (C) 2012,2013  Toni Gundogdu <legatvs@gmail.com>
 -- Copyright (C) 2010  Paul Kocialkowski <contact@paulk.fr>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -46,12 +46,15 @@ function parse(self)
 
     local p = quvi.fetch(self.page_url)
 
-    self.title = p:match("<title>TagTélé%s+-%s+(.-)</title>")
-                  or error("no match: media title")
+    self.title = p:match('meta name="title" content="(.-)"')
+                  or p:match('meta property="og:title" content="(.-)"')
+                    or error("no match: media title")
 
     self.id = self.page_url:match('/voir/(%d+)')
                 or error("no match: media ID")
 
+    self.thumbnail_url = p:match('og:image" content="(.-)"') or ''
+
     local pl_url = "http://www.tagtele.com/videos/playlist/"..self.id.."/"
     local pl = quvi.fetch(pl_url, {fetch_type='playlist'})
 
